FluentEmojiData class

Implementers

Constructors

FluentEmojiData({required String package, required String group, required String name, required String glyph, required String svgPath, required String tts, required String fromVersion, required List<String>? glyphAsUtfInEmoticons, required List<String>? keywords, required List<String>? mappedToEmoticons, required FluentEmojiSkinTone skinTone})
const

Properties

fromVersion String
final
glyph String
final
glyphAsUtfInEmoticons List<String>?
final
group String
final
hashCode int
The hash code for this object.
no setterinherited
keywords List<String>?
final
mappedToEmoticons List<String>?
final
name String
final
package String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skinTone FluentEmojiSkinTone
final
svgPath String
final
tts String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited